@@ -19,7 +19,6 @@
 #
 
 set -e        # exit on error
-#set -x
 
 root_dir=$(pwd)
 build_dir="../../build/c"
@@ -43,53 +42,62 @@ function clean {
   rm -f examples/quickstop.db
 }
 
-case "$1" in
+for target in "$@"
+do
 
-  interop-data-generate)
-    prepare_build
-    make -C $build_dir
-    $build_dir/tests/generate_interop_data "../../share/test/schemas/interop.avsc"  "../../build/interop/data"
-    ;;
+  case "$target" in
 
-  interop-data-test)
-    prepare_build
-    make -C $build_dir
-    $build_dir/tests/test_interop_data "../../build/interop/data"
-    ;;
+    interop-data-generate)
+      prepare_build
+      make -C $build_dir
+      $build_dir/tests/generate_interop_data "../../share/test/schemas/interop.avsc"  "../../build/interop/data"
+      ;;
 
-  test)
-    prepare_build
-    make -C $build_dir
-    make -C $build_dir test
-    ;;
+    interop-data-test)
+      prepare_build
+      make -C $build_dir
+      $build_dir/tests/test_interop_data "../../build/interop/data"
+      ;;
 
-  dist)
-    prepare_build
-    cp ../../share/VERSION.txt $root_dir
-    make -C $build_dir docs
-    # This is a hack to force the built documentation to be included
-    # in the source package.
-    cp $build_dir/docs/*.html $root_dir/docs
-    make -C $build_dir package_source
-    rm $root_dir/docs/*.html
-    if [ ! -d $dist_dir ]; then
-      mkdir -p $dist_dir
-    fi
-    if [ ! -d $doc_dir ]; then
-      mkdir -p $doc_dir
-    fi
-    mv $build_dir/$tarball $dist_dir
-    cp $build_dir/docs/*.html $doc_dir
-    clean
-    ;;
+    lint)
+      echo 'This is a stub where someone can provide linting.'
+      ;;
 
-  clean)
-    clean
-    ;;
+    test)
+      prepare_build
+      make -C $build_dir
+      make -C $build_dir test
+      ;;
 
-  *)
-    echo "Usage: $0 {interop-data-generate|interop-data-test|test|dist|clean}"
-    exit 1
-esac
+    dist)
+      prepare_build
+      cp ../../share/VERSION.txt $root_dir
+      make -C $build_dir docs
+      # This is a hack to force the built documentation to be included
+      # in the source package.
+      cp $build_dir/docs/*.html $root_dir/docs
+      make -C $build_dir package_source
+      rm $root_dir/docs/*.html
+      if [ ! -d $dist_dir ]; then
+        mkdir -p $dist_dir
+      fi
+      if [ ! -d $doc_dir ]; then
+        mkdir -p $doc_dir
+      fi
+      mv $build_dir/$tarball $dist_dir
+      cp $build_dir/docs/*.html $doc_dir
+      clean
+      ;;
+
+    clean)
+      clean
+      ;;
+
+    *)
+      echo "Usage: $0 {interop-data-generate|interop-data-test|lint|test|dist|clean}"
+      exit 1
+  esac
+
+done
 
 exit 0
